package org.dromara.domain.checkPoint.bo;

import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.domain.checkPoint.CheckPointRecord;

import java.util.Date;

/**
 * 巡更点记录业务对象 check_point_record
 *
 * @author boman
 * @date 2025-04-11
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = CheckPointRecord.class, reverseConvertGenerate = false)
public class CheckPointRecordBo extends BaseEntity {

    /**
     * 巡更点记录id
     */
    @NotNull(message = "巡更点记录id不能为空", groups = { EditGroup.class })
    private Long checkPointRecordId;

    /**
     * 巡更点id
     */
    private Long checkPointManageId;

    /**
     * 星期几
     */
    private String dateTimeNum;

    /**
     * 巡更类型(字典值)
     */
    @NotBlank(message = "巡更类型(字典值)不能为空", groups = { AddGroup.class, EditGroup.class })
    private String checkType;

    /**
     * 巡更设定时间
     */
    private Date checkTime;

    /**
     * 巡更路线
     */
    private String checkAddress;

    /**
     * 巡更人负责人姓名
     */
    private String userName;

    /**
     * 巡更人负责人id
     */
    private Long useId;

    /**
     * 巡更人姓名
     */
    private String checkUserName;

    /**
     * 巡更人id
     */
    private Long checkUseId;

    /**
     * 巡更人员工管理id
     */
    private Long checkStaffId;

    /**
     * 巡更人手机号
     */
    private String checkUsePhone;

    /**
     * 巡更结果 1：正常 2：损坏
     */
    private String checkResult;

    /**
     * 巡更结果详情
     */
    private String checkResultDetails;

    /**
     * 巡更结果照片
     */
    private String checkResultPhoto;

    /**
     * 巡更完成时间
     */
    private Date checkResultTime;

    /**
     * 是否巡更 1:未巡更 2:已巡更
     */
    private String checkStatus;

    /**
     * 备注
     */
    private String remark;


}
