package org.dromara.domain.communityNews.bo;

import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.domain.communityNews.CommentIndex;

/**
 * 社区资讯评论业务对象 comment_index
 *
 * @author boman
 * @date 2025-04-11
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = CommentIndex.class, reverseConvertGenerate = false)
public class CommentIndexBo extends BaseEntity {

    /**
     * 社区资讯评论ID
     */
    @NotNull(message = "社区资讯评论ID不能为空", groups = { EditGroup.class })
    private Long commentId;

    /**
     * 社区资讯ID
     */
    @NotNull(message = "社区资讯ID不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long communityId;

    /**
     * 社区资讯类型（1：公告 2：通知 3：资讯）
     */
    @NotBlank(message = "社区资讯类型（1：公告 2：通知 3：资讯）不能为空", groups = { AddGroup.class, EditGroup.class })
    private String communityType;

    /**
     * 社区资讯标题
     */
    private String communityTitle;

    /**
     * 根评论id 1:根评论 2：子评论
     */
    private Long isRoot;

    /**
     * 父评论id
     */
    private Long parentId;

    /**
     * 用户id
     */
    private Long userId;

    /**
     * 用户昵称
     */
    private String nickName;

    /**
     * 头像地址
     */
    private String avatar;

    /**
     * 所回复目标评论的用户id
     */
    private Long toUserId;

    /**
     * 所回复目标评论的用户昵称
     */
    private String toNickName;

    /**
     * 所回复目标评论的头像地址
     */
    private String toAvatar;

    /**
     * 是否是二级回复的回复 Y:是 N:否
     */
    private String toRoot;

    /**
     * 内容id
     */
    private Long contentId;

    /**
     * 评论内容(冗余字段)
     */
    private String commentContent;

    /**
     * 备注
     */
    private String remark;


}
