package org.dromara.domain.communityNews.bo;

import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.domain.communityNews.CommunityNews;

import java.util.Date;

/**
 * 社区资讯业务对象 community_news
 *
 * @author boman
 * @date 2025-04-11
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = CommunityNews.class, reverseConvertGenerate = false)
public class CommunityNewsBo extends BaseEntity {

    /**
     * 社区资讯ID
     */
    @NotNull(message = "社区资讯ID不能为空", groups = { EditGroup.class })
    private Long communityId;

    /**
     * 社区资讯标题
     */
    @NotBlank(message = "社区资讯标题不能为空", groups = { AddGroup.class, EditGroup.class })
    private String communityTitle;

    /**
     * 社区资讯类型（1：公告 2：通知 3：资讯）
     */
    @NotBlank(message = "社区资讯类型（1：公告 2：通知 3：资讯）不能为空", groups = { AddGroup.class, EditGroup.class })
    private String communityType;

    /**
     * 社区资讯内容
     */
    private String communityContent;

    /**
     * 社区资讯状态（1正常 2关闭）
     */
    private String status;

    /**
     * 发布时间
     */
    private Date publishTime;

    /**
     * 用户id
     */
    private Long userId;

    /**
     * 员工管理id
     */
    private Long staffId;

    /**
     * 员工姓名
     */
    private String staffName;

    /**
     * 作者，记录资讯的发布者
     */
    private String author;

    /**
     * 来源，记录资讯的来源（如单位、网站等）
     */
    private String source;

    /**
     * 封面图片，存储图片路径或URL
     */
    private String coverImage;

    /**
     * 浏览次数，记录资讯被查看的次数
     */
    private Long viewCount;

    /**
     * 是否置顶：Y（置顶）、N（不置顶）
     */
    private String isTop;

    /**
     * 评论数量
     */
    private String userComment;

    /**
     * 点赞数量
     */
    private String userLikes;

    /**
     * 收藏数量
     */
    private String userStars;

    /**
     * 备注
     */
    private String remark;


}
