package org.dromara.domain.communityNews.vo;

import com.alibaba.excel.annotation.ExcelIgnoreUnannotated;
import com.alibaba.excel.annotation.ExcelProperty;
import io.github.linpeilie.annotations.AutoMapper;
import lombok.Data;
import org.dromara.common.excel.annotation.ExcelDictFormat;
import org.dromara.common.excel.convert.ExcelDictConvert;
import org.dromara.domain.communityNews.CommentIndex;

import java.io.Serial;
import java.io.Serializable;



/**
 * 社区资讯评论视图对象 comment_index
 *
 * @author boman
 * @date 2025-04-11
 */
@Data
@ExcelIgnoreUnannotated
@AutoMapper(target = CommentIndex.class)
public class CommentIndexVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 社区资讯评论ID
     */
    @ExcelProperty(value = "社区资讯评论ID")
    private Long commentId;

    /**
     * 社区资讯ID
     */
    @ExcelProperty(value = "社区资讯ID")
    private Long communityId;

    /**
     * 社区资讯类型（1：公告 2：通知 3：资讯）
     */
    @ExcelProperty(value = "社区资讯类型", converter = ExcelDictConvert.class)
    @ExcelDictFormat(readConverterExp = "1=：公告,2=：通知,3=：资讯")
    private String communityType;

    /**
     * 社区资讯标题
     */
    @ExcelProperty(value = "社区资讯标题")
    private String communityTitle;

    /**
     * 根评论id 1:根评论 2：子评论
     */
    @ExcelProperty(value = "根评论id 1:根评论 2：子评论")
    private Long isRoot;

    /**
     * 父评论id
     */
    @ExcelProperty(value = "父评论id")
    private Long parentId;

    /**
     * 用户id
     */
    @ExcelProperty(value = "用户id")
    private Long userId;

    /**
     * 用户昵称
     */
    @ExcelProperty(value = "用户昵称")
    private String nickName;

    /**
     * 头像地址
     */
    @ExcelProperty(value = "头像地址")
    private String avatar;

    /**
     * 所回复目标评论的用户id
     */
    @ExcelProperty(value = "所回复目标评论的用户id")
    private Long toUserId;

    /**
     * 所回复目标评论的用户昵称
     */
    @ExcelProperty(value = "所回复目标评论的用户昵称")
    private String toNickName;

    /**
     * 所回复目标评论的头像地址
     */
    @ExcelProperty(value = "所回复目标评论的头像地址")
    private String toAvatar;

    /**
     * 是否是二级回复的回复 Y:是 N:否
     */
    @ExcelProperty(value = "是否是二级回复的回复 Y:是 N:否")
    private String toRoot;

    /**
     * 内容id
     */
    @ExcelProperty(value = "内容id")
    private Long contentId;

    /**
     * 评论内容(冗余字段)
     */
    @ExcelProperty(value = "评论内容(冗余字段)")
    private String commentContent;

    /**
     * 备注
     */
    @ExcelProperty(value = "备注")
    private String remark;


}
