package org.dromara.domain.illegalParking.bo;

import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.domain.illegalParking.IllegalParking;

/**
 * 违章停车登记业务对象 illegal_parking
 *
 * @author boman
 * @date 2025-04-11
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = IllegalParking.class, reverseConvertGenerate = false)
public class IllegalParkingBo extends BaseEntity {

    /**
     * 违章停车登记主键
     */
    @NotNull(message = "违章停车登记主键不能为空", groups = { EditGroup.class })
    private Long illegalParkingId;

    /**
     * 车牌号码
     */
    @NotBlank(message = "车牌号码不能为空", groups = { AddGroup.class, EditGroup.class })
    private String plateNumber;

    /**
     * 门户id
     */
    private Long portalId;

    /**
     * 关联门户
     */
    private String visitPortal;

    /**
     * 手机号码
     */
    private String mobileNumber;

    /**
     * 人员姓名
     */
    private String visitName;

    /**
     * 违章照片
     */
    private String illegalPhoto;

    /**
     * 车辆类型 1：小区车辆 2：外来车辆
     */
    private String carType;

    /**
     * 是否黑名单 N:否 Y:是
     */
    private String isBlack;

    /**
     * 备注
     */
    private String remark;


}
