package org.dromara.domain.partyNews.bo;

import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.domain.partyNews.PartyNews;

import java.util.Date;

/**
 * 党建资讯业务对象 party_news
 *
 * @author boman
 * @date 2025-04-11
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = PartyNews.class, reverseConvertGenerate = false)
public class PartyNewsBo extends BaseEntity {

    /**
     * 资讯ID
     */
    @NotNull(message = "资讯ID不能为空", groups = { EditGroup.class })
    private Long partyId;

    /**
     * 党建资讯标题
     */
    @NotBlank(message = "党建资讯标题不能为空", groups = { AddGroup.class, EditGroup.class })
    private String partyTitle;

    /**
     * 党建资讯类型（1：党建活动 2：党建学习3：党建知识）
     */
    @NotBlank(message = "党建资讯类型（1：党建活动 2：党建学习3：党建知识）不能为空", groups = { AddGroup.class, EditGroup.class })
    private String partyType;

    /**
     * 党建资讯内容
     */
    private String partyContent;

    /**
     * 党建资讯状态（1正常 2关闭）
     */
    private String status;

    /**
     * 发布时间
     */
    private Date publishTime;

    /**
     * 作者，记录资讯的发布者
     */
    private String author;

    /**
     * 来源，记录资讯的来源（如单位、网站等）
     */
    private String source;

    /**
     * 封面图片，存储图片路径或URL
     */
    private String coverImage;

    /**
     * 浏览次数，记录资讯被查看的次数
     */
    private Long viewCount;

    /**
     * 是否置顶：Y（置顶）、N（不置顶）
     */
    private String isTop;

    /**
     * 备注
     */
    private String remark;


}
