package org.dromara.domain.reservRecord.bo;

import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.domain.reservRecord.ReservRecord;

import java.util.Date;

/**
 * 预约记录业务对象 reserv_record
 *
 * @author boman
 * @date 2025-04-11
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = ReservRecord.class, reverseConvertGenerate = false)
public class ReservRecordBo extends BaseEntity {

    /**
     * 预约主键
     */
    @NotNull(message = "预约主键不能为空", groups = { EditGroup.class })
    private Long reservRecordId;

    /**
     * 门户id 房屋信息表的id
     */
    @NotNull(message = "门户id 房屋信息表的id不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long portalId;

    /**
     * 详细门牌号
     */
    @NotBlank(message = "详细门牌号不能为空", groups = { AddGroup.class, EditGroup.class })
    private String houseAddress;

    /**
     * 详细地址
     */
    @NotBlank(message = "详细地址不能为空", groups = { AddGroup.class, EditGroup.class })
    private String detailAddress;

    /**
     * 经度
     */
    @NotBlank(message = "经度不能为空", groups = { AddGroup.class, EditGroup.class })
    private String lgt;

    /**
     * 纬度
     */
    @NotBlank(message = "纬度不能为空", groups = { AddGroup.class, EditGroup.class })
    private String lat;

    /**
     * 分享人姓名
     */
    private String shareName;

    /**
     * 访客姓名
     */
    private String name;

    /**
     * 来访人数
     */
    private String num;

    /**
     * 来访事由
     */
    private String reason;

    /**
     * 手机号码
     */
    @NotBlank(message = "手机号码不能为空", groups = { AddGroup.class, EditGroup.class })
    private String mobileNumber;

    /**
     * 是否驾车 N:否 Y:是
     */
    private String isCar;

    /**
     * 车牌号码
     */
    private String plateNumber;

    /**
     * 预约时间
     */
    private Date reserveTime;

    /**
     * 来访时间
     */
    private Date visitorTime;

    /**
     * 状态 1：待来访 2：已来访 3：已过期
     */
    private String status;

    /**
     * 人脸信息
     */
    private String photo;

    /**
     * 备注
     */
    private String remark;


}
