package org.dromara.domain.residentInfo.bo;

import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.domain.residentInfo.ResidentInfo;

/**
 * 居住人员信息，存储居住人员的详细信息业务对象 resident_info
 *
 * @author boman
 * @date 2025-04-11
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = ResidentInfo.class, reverseConvertGenerate = false)
public class ResidentInfoBo extends BaseEntity {

    /**
     * 居住人员主键，唯一标识每条居住人员信息
     */
    @NotNull(message = "居住人员主键，唯一标识每条居住人员信息不能为空", groups = { EditGroup.class })
    private Long residentId;

    /**
     * 关联房屋信息表的house_id，标识居住人员所属房屋
     */
    @NotNull(message = "关联房屋信息表的house_id，标识居住人员所属房屋不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long houseId;

    /**
     * 关联sys_user表中user_id
     */
    private Long userId;

    /**
     * 居住人员的详细门牌号
     */
    private String detailedAddress;

    /**
     * 居住人员姓名
     */
    private String residentName;

    /**
     * 居住人员身份证号码，18位
     */
    private String residentIdCard;

    /**
     * 居住人员出生日期
     */
    private String residentBirthday;

    /**
     * 居住人员手机号
     */
    private String residentPhone;

    /**
     * 居住人员性别：1-男，2-女
     */
    private Long residentGender;

    /**
     * 居住人员与户主的关系，如父子、夫妻等
     */
    private String residentRelationship;

    /**
     * 是否是户主：Y-是，N-否
     */
    private String isHouseholder;

    /**
     * 是否是租户：Y-是，N-否
     */
    private String isTenant;

    /**
     * 居住人员工作单位
     */
    private String residentEmployer;

    /**
     * 特殊类型
     */
    private String specialType;

    /**
     * 爱好字典值多选
     */
    private String residentHobby;

    /**
     * 居住人员面貌，如党员、群众等
     */
    private String residentAppearance;

    /**
     * 身份证正面
     */
    private String idCardFront;

    /**
     * 身份证反面
     */
    private String idCardBack;

    /**
     * 身份证住址
     */
    private String idCardAddress;

    /**
     * 人脸地址
     */
    private String facePhoto;

    /**
     * 备注
     */
    private String remark;


}
