package org.dromara.domain.staffManage.bo;


import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.dromara.common.core.validate.EditGroup;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.domain.staffManage.StaffManage;

/**
 * 员工管理业务对象 staff_manage
 *
 * @author boman
 * @date 2025-04-10
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = StaffManage.class, reverseConvertGenerate = false)
public class StaffManageBo extends BaseEntity {

    /**
     * 员工管理id
     */
    @NotNull(message = "员工管理id不能为空", groups = { EditGroup.class })
    private Long staffId;

    private String userType;

    /**
     * 租户ID
     */
    private String tenantId;
    /**
     * 员工账号id
     */
    private Long userId;

    /**
     * 员工姓名
     */
    private String staffName;

    /**
     * 员工性别（1男 2女 ）
     */
    private String gender;

    /**
     * 员工类别，1：保安 2:维修人员 3：物业管理
     */
    private String staffCategory;

    /**
     * 维修分类，表示维修人员擅长的维修类别
     */
    private String maintenanceCategory;

    /**
     * 手机号码
     */
    private String phoneNumber;

    /**
     * 头像，存储头像的URL或文件路径
     */
    private String avatarPhoto;

    /**
     * 身份证号码
     */
    private String idCard;

    /**
     * 身份证正面
     */
    private String idCardFront;

    /**
     * 身份证反面
     */
    private String idCardBack;

    /**
     * 相关证件
     */
    private String certificate;

    /**
     * 状态，字典值 1：空闲2：忙碌
     */
    private String status;

    /**
     * 备注
     */
    private String remark;

    /**
     * 审核状态 1:未审核 2：审核通过 3：审核未通过
     */
    private String examine;
}
