package org.dromara.domain.staffTrain.bo;

import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.domain.staffTrain.StaffTrainManual;

import java.util.Date;

/**
 * 员工培训手册业务对象 staff_train_manual
 *
 * @author boman
 * @date 2025-04-11
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = StaffTrainManual.class, reverseConvertGenerate = false)
public class StaffTrainManualBo extends BaseEntity {

    /**
     * 员工培训手册ID
     */
    @NotNull(message = "员工培训手册ID不能为空", groups = { EditGroup.class })
    private Long manualId;

    /**
     * 员工培训手册标题
     */
    @NotBlank(message = "员工培训手册标题不能为空", groups = { AddGroup.class, EditGroup.class })
    private String manualTitle;

    /**
     * 员工培训手册类型（1：图片 2:视频）
     */
    @NotBlank(message = "员工培训手册类型（1：图片 2:视频）不能为空", groups = { AddGroup.class, EditGroup.class })
    private String manualType;

    /**
     * 员工培训手册内容
     */
    private String manualContent;

    /**
     * 员工培训手册状态（0正常 1关闭）
     */
    private String status;

    /**
     * 发布时间
     */
    private Date publishTime;

    /**
     * 视频地址URL
     */
    private String videoUrl;

    /**
     * 封面图片，存储图片路径或URL
     */
    private String coverImage;

    /**
     * 作者，记录资讯的发布者
     */
    private String author;

    /**
     * 来源，记录资讯的来源（如单位、网站等）
     */
    private String source;

    /**
     * 浏览次数，记录资讯被查看的次数
     */
    private Long viewCount;

    /**
     * 进度
     */
    private String progress;

    /**
     * 是否置顶：Y（置顶）、N（不置顶）
     */
    private String isTop;

    /**
     * 备注
     */
    private String remark;


}
