package org.dromara.domain.staffTrain.vo;

import com.alibaba.excel.annotation.ExcelIgnoreUnannotated;
import com.alibaba.excel.annotation.ExcelProperty;
import io.github.linpeilie.annotations.AutoMapper;
import lombok.Data;
import org.dromara.common.excel.annotation.ExcelDictFormat;
import org.dromara.common.excel.convert.ExcelDictConvert;
import org.dromara.common.translation.annotation.Translation;
import org.dromara.common.translation.constant.TransConstant;
import org.dromara.domain.staffTrain.StaffTrainManual;

import java.io.Serial;
import java.io.Serializable;
import java.util.Date;



/**
 * 员工培训手册视图对象 staff_train_manual
 *
 * @author boman
 * @date 2025-04-11
 */
@Data
@ExcelIgnoreUnannotated
@AutoMapper(target = StaffTrainManual.class)
public class StaffTrainManualVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 员工培训手册ID
     */
    @ExcelProperty(value = "员工培训手册ID")
    private Long manualId;

    /**
     * 员工培训手册标题
     */
    @ExcelProperty(value = "员工培训手册标题")
    private String manualTitle;

    /**
     * 员工培训手册类型（1：图片 2:视频）
     */
    @ExcelProperty(value = "员工培训手册类型", converter = ExcelDictConvert.class)
    @ExcelDictFormat(readConverterExp = "1=：图片,2=:视频")
    private String manualType;

    /**
     * 员工培训手册内容
     */
    @ExcelProperty(value = "员工培训手册内容")
    private String manualContent;

    /**
     * 员工培训手册状态（0正常 1关闭）
     */
    @ExcelProperty(value = "员工培训手册状态", converter = ExcelDictConvert.class)
    @ExcelDictFormat(readConverterExp = "0=正常,1=关闭")
    private String status;

    /**
     * 发布时间
     */
    @ExcelProperty(value = "发布时间")
    private Date publishTime;

    /**
     * 视频地址URL
     */
    @ExcelProperty(value = "视频地址URL")
    private String videoUrl;

    /**
     * 封面图片，存储图片路径或URL
     */
    @ExcelProperty(value = "封面图片，存储图片路径或URL")
    private String coverImage;

    /**
     * 封面图片，存储图片路径或URLUrl
     */
    @Translation(type = TransConstant.OSS_ID_TO_URL, mapper = "coverImage")
    private String coverImageUrl;
    /**
     * 作者，记录资讯的发布者
     */
    @ExcelProperty(value = "作者，记录资讯的发布者")
    private String author;

    /**
     * 来源，记录资讯的来源（如单位、网站等）
     */
    @ExcelProperty(value = "来源，记录资讯的来源", converter = ExcelDictConvert.class)
    @ExcelDictFormat(readConverterExp = "如=单位、网站等")
    private String source;

    /**
     * 浏览次数，记录资讯被查看的次数
     */
    @ExcelProperty(value = "浏览次数，记录资讯被查看的次数")
    private Long viewCount;

    /**
     * 进度
     */
    @ExcelProperty(value = "进度")
    private String progress;

    /**
     * 是否置顶：Y（置顶）、N（不置顶）
     */
    @ExcelProperty(value = "是否置顶：Y", converter = ExcelDictConvert.class)
    @ExcelDictFormat(readConverterExp = "置=顶")
    private String isTop;

    /**
     * 备注
     */
    @ExcelProperty(value = "备注")
    private String remark;


}
