package org.dromara.domain.visitor.bo;

import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.domain.visitor.VisitorManage;

import java.util.Date;

/**
 * 来访管理业务对象 visitor_manage
 *
 * @author boman
 * @date 2025-04-11
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = VisitorManage.class, reverseConvertGenerate = false)
public class VisitorManageBo extends BaseEntity {

    /**
     * 来访主键
     */
    @NotNull(message = "来访主键不能为空", groups = { EditGroup.class })
    private Long visitorManageId;

    /**
     * 门户id
     */
    @NotNull(message = "门户id不能为空", groups = { AddGroup.class, EditGroup.class })
    private Long portalId;

    /**
     * 详细门牌号
     */
    @NotBlank(message = "详细门牌号不能为空", groups = { AddGroup.class, EditGroup.class })
    private String houseAddress;

    /**
     * 访客姓名
     */
    private String name;

    /**
     * 来访人数
     */
    private String num;

    /**
     * 来访事由
     */
    private String reason;

    /**
     * 手机号码
     */
    @NotBlank(message = "手机号码不能为空", groups = { AddGroup.class, EditGroup.class })
    private String mobileNumber;

    /**
     * 是否驾车 N:否 Y:是
     */
    private String isCar;

    /**
     * 车牌号码
     */
    private String plateNumber;

    /**
     * 预约时间
     */
    private Date reserveTime;

    /**
     * 来访时间
     */
    private Date visitorTime;

    /**
     * 状态 1：已来访
     */
    private String status;

    /**
     * 人脸信息
     */
    private String photo;

    /**
     * 备注
     */
    private String remark;


}
