package org.dromara.service;


import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.asset.bo.AssetTypeBo;
import org.dromara.domain.asset.vo.AssetTypeVo;

import java.util.Collection;
import java.util.List;

/**
 * 资产类型Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface IAssetTypeService {

    /**
     * 查询资产类型
     *
     * @param assetId 主键
     * @return 资产类型
     */
    AssetTypeVo queryById(Long assetId);

    /**
     * 分页查询资产类型列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 资产类型分页列表
     */
    TableDataInfo<AssetTypeVo> queryPageList(AssetTypeBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的资产类型列表
     *
     * @param bo 查询条件
     * @return 资产类型列表
     */
    List<AssetTypeVo> queryList(AssetTypeBo bo);

    /**
     * 新增资产类型
     *
     * @param bo 资产类型
     * @return 是否新增成功
     */
    Boolean insertByBo(AssetTypeBo bo);

    /**
     * 修改资产类型
     *
     * @param bo 资产类型
     * @return 是否修改成功
     */
    Boolean updateByBo(AssetTypeBo bo);

    /**
     * 校验并批量删除资产类型信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
