package org.dromara.service;

import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.checkPoint.bo.CheckPointRecordBo;
import org.dromara.domain.checkPoint.vo.CheckPointRecordVo;

import java.util.Collection;
import java.util.List;

/**
 * 巡更点记录Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface ICheckPointRecordService {

    /**
     * 查询巡更点记录
     *
     * @param checkPointRecordId 主键
     * @return 巡更点记录
     */
    CheckPointRecordVo queryById(Long checkPointRecordId);

    /**
     * 分页查询巡更点记录列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 巡更点记录分页列表
     */
    TableDataInfo<CheckPointRecordVo> queryPageList(CheckPointRecordBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的巡更点记录列表
     *
     * @param bo 查询条件
     * @return 巡更点记录列表
     */
    List<CheckPointRecordVo> queryList(CheckPointRecordBo bo);

    /**
     * 新增巡更点记录
     *
     * @param bo 巡更点记录
     * @return 是否新增成功
     */
    Boolean insertByBo(CheckPointRecordBo bo);

    /**
     * 修改巡更点记录
     *
     * @param bo 巡更点记录
     * @return 是否修改成功
     */
    Boolean updateByBo(CheckPointRecordBo bo);

    /**
     * 校验并批量删除巡更点记录信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
