package org.dromara.service;

import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.communityNews.bo.CommentContentBo;
import org.dromara.domain.communityNews.vo.CommentContentVo;

import java.util.Collection;
import java.util.List;

/**
 * 社区资讯评论内容Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface ICommentContentService {

    /**
     * 查询社区资讯评论内容
     *
     * @param contentId 主键
     * @return 社区资讯评论内容
     */
    CommentContentVo queryById(Long contentId);

    /**
     * 分页查询社区资讯评论内容列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 社区资讯评论内容分页列表
     */
    TableDataInfo<CommentContentVo> queryPageList(CommentContentBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的社区资讯评论内容列表
     *
     * @param bo 查询条件
     * @return 社区资讯评论内容列表
     */
    List<CommentContentVo> queryList(CommentContentBo bo);

    /**
     * 新增社区资讯评论内容
     *
     * @param bo 社区资讯评论内容
     * @return 是否新增成功
     */
    Boolean insertByBo(CommentContentBo bo);

    /**
     * 修改社区资讯评论内容
     *
     * @param bo 社区资讯评论内容
     * @return 是否修改成功
     */
    Boolean updateByBo(CommentContentBo bo);

    /**
     * 校验并批量删除社区资讯评论内容信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
