package org.dromara.service;

import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.communityNews.bo.CommentStarsBo;
import org.dromara.domain.communityNews.vo.CommentStarsVo;

import java.util.Collection;
import java.util.List;

/**
 * 社区资讯收藏Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface ICommentStarsService {

    /**
     * 查询社区资讯收藏
     *
     * @param starsId 主键
     * @return 社区资讯收藏
     */
    CommentStarsVo queryById(Long starsId);

    /**
     * 分页查询社区资讯收藏列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 社区资讯收藏分页列表
     */
    TableDataInfo<CommentStarsVo> queryPageList(CommentStarsBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的社区资讯收藏列表
     *
     * @param bo 查询条件
     * @return 社区资讯收藏列表
     */
    List<CommentStarsVo> queryList(CommentStarsBo bo);

    /**
     * 新增社区资讯收藏
     *
     * @param bo 社区资讯收藏
     * @return 是否新增成功
     */
    Boolean insertByBo(CommentStarsBo bo);

    /**
     * 修改社区资讯收藏
     *
     * @param bo 社区资讯收藏
     * @return 是否修改成功
     */
    Boolean updateByBo(CommentStarsBo bo);

    /**
     * 校验并批量删除社区资讯收藏信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
