package org.dromara.service;

import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.assets.bo.CommunityAssetsBo;
import org.dromara.domain.assets.vo.CommunityAssetsVo;

import java.util.Collection;
import java.util.List;

/**
 * 社区资产Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface ICommunityAssetsService {

    /**
     * 查询社区资产
     *
     * @param communityAssetId 主键
     * @return 社区资产
     */
    CommunityAssetsVo queryById(Long communityAssetId);

    /**
     * 分页查询社区资产列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 社区资产分页列表
     */
    TableDataInfo<CommunityAssetsVo> queryPageList(CommunityAssetsBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的社区资产列表
     *
     * @param bo 查询条件
     * @return 社区资产列表
     */
    List<CommunityAssetsVo> queryList(CommunityAssetsBo bo);

    /**
     * 新增社区资产
     *
     * @param bo 社区资产
     * @return 是否新增成功
     */
    Boolean insertByBo(CommunityAssetsBo bo);

    /**
     * 修改社区资产
     *
     * @param bo 社区资产
     * @return 是否修改成功
     */
    Boolean updateByBo(CommunityAssetsBo bo);

    /**
     * 校验并批量删除社区资产信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
