package org.dromara.service;

import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.communityNews.bo.CommunityNewsBo;
import org.dromara.domain.communityNews.vo.CommunityNewsVo;

import java.util.Collection;
import java.util.List;

/**
 * 社区资讯Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface ICommunityNewsService {

    /**
     * 查询社区资讯
     *
     * @param communityId 主键
     * @return 社区资讯
     */
    CommunityNewsVo queryById(Long communityId);

    /**
     * 分页查询社区资讯列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 社区资讯分页列表
     */
    TableDataInfo<CommunityNewsVo> queryPageList(CommunityNewsBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的社区资讯列表
     *
     * @param bo 查询条件
     * @return 社区资讯列表
     */
    List<CommunityNewsVo> queryList(CommunityNewsBo bo);

    /**
     * 新增社区资讯
     *
     * @param bo 社区资讯
     * @return 是否新增成功
     */
    Boolean insertByBo(CommunityNewsBo bo);

    /**
     * 修改社区资讯
     *
     * @param bo 社区资讯
     * @return 是否修改成功
     */
    Boolean updateByBo(CommunityNewsBo bo);

    /**
     * 校验并批量删除社区资讯信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
