package org.dromara.service;


import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.complaintSuggestion.bo.ComplaintSuggestionBo;
import org.dromara.domain.complaintSuggestion.vo.ComplaintSuggestionVo;

import java.util.Collection;
import java.util.List;

/**
 * 投诉建议Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface IComplaintSuggestionService {

    /**
     * 查询投诉建议
     *
     * @param suggestionId 主键
     * @return 投诉建议
     */
    ComplaintSuggestionVo queryById(Long suggestionId);

    /**
     * 分页查询投诉建议列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 投诉建议分页列表
     */
    TableDataInfo<ComplaintSuggestionVo> queryPageList(ComplaintSuggestionBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的投诉建议列表
     *
     * @param bo 查询条件
     * @return 投诉建议列表
     */
    List<ComplaintSuggestionVo> queryList(ComplaintSuggestionBo bo);

    /**
     * 新增投诉建议
     *
     * @param bo 投诉建议
     * @return 是否新增成功
     */
    Boolean insertByBo(ComplaintSuggestionBo bo);

    /**
     * 修改投诉建议
     *
     * @param bo 投诉建议
     * @return 是否修改成功
     */
    Boolean updateByBo(ComplaintSuggestionBo bo);

    /**
     * 校验并批量删除投诉建议信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
