package org.dromara.service;


import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.houseInfo.bo.HouseInfoBo;
import org.dromara.domain.houseInfo.vo.HouseInfoVo;

import java.util.Collection;
import java.util.List;

/**
 * 房屋信息Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface IHouseInfoService {

    /**
     * 查询房屋信息
     *
     * @param houseId 主键
     * @return 房屋信息
     */
    HouseInfoVo queryById(Long houseId);

    /**
     * 分页查询房屋信息列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 房屋信息分页列表
     */
    TableDataInfo<HouseInfoVo> queryPageList(HouseInfoBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的房屋信息列表
     *
     * @param bo 查询条件
     * @return 房屋信息列表
     */
    List<HouseInfoVo> queryList(HouseInfoBo bo);

    /**
     * 新增房屋信息
     *
     * @param bo 房屋信息
     * @return 是否新增成功
     */
    Boolean insertByBo(HouseInfoBo bo);

    /**
     * 修改房屋信息
     *
     * @param bo 房屋信息
     * @return 是否修改成功
     */
    Boolean updateByBo(HouseInfoBo bo);

    /**
     * 校验并批量删除房屋信息信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
