package org.dromara.service;


import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.illegalParking.bo.IllegalParkingBo;
import org.dromara.domain.illegalParking.vo.IllegalParkingVo;

import java.util.Collection;
import java.util.List;

/**
 * 违章停车登记Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface IIllegalParkingService {

    /**
     * 查询违章停车登记
     *
     * @param illegalParkingId 主键
     * @return 违章停车登记
     */
    IllegalParkingVo queryById(Long illegalParkingId);

    /**
     * 分页查询违章停车登记列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 违章停车登记分页列表
     */
    TableDataInfo<IllegalParkingVo> queryPageList(IllegalParkingBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的违章停车登记列表
     *
     * @param bo 查询条件
     * @return 违章停车登记列表
     */
    List<IllegalParkingVo> queryList(IllegalParkingBo bo);

    /**
     * 新增违章停车登记
     *
     * @param bo 违章停车登记
     * @return 是否新增成功
     */
    Boolean insertByBo(IllegalParkingBo bo);

    /**
     * 修改违章停车登记
     *
     * @param bo 违章停车登记
     * @return 是否修改成功
     */
    Boolean updateByBo(IllegalParkingBo bo);

    /**
     * 校验并批量删除违章停车登记信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
