package org.dromara.service;

import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.partyNews.bo.PartyNewsBo;
import org.dromara.domain.partyNews.vo.PartyNewsVo;

import java.util.Collection;
import java.util.List;

/**
 * 党建资讯Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface IPartyNewsService {

    /**
     * 查询党建资讯
     *
     * @param partyId 主键
     * @return 党建资讯
     */
    PartyNewsVo queryById(Long partyId);

    /**
     * 分页查询党建资讯列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 党建资讯分页列表
     */
    TableDataInfo<PartyNewsVo> queryPageList(PartyNewsBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的党建资讯列表
     *
     * @param bo 查询条件
     * @return 党建资讯列表
     */
    List<PartyNewsVo> queryList(PartyNewsBo bo);

    /**
     * 新增党建资讯
     *
     * @param bo 党建资讯
     * @return 是否新增成功
     */
    Boolean insertByBo(PartyNewsBo bo);

    /**
     * 修改党建资讯
     *
     * @param bo 党建资讯
     * @return 是否修改成功
     */
    Boolean updateByBo(PartyNewsBo bo);

    /**
     * 校验并批量删除党建资讯信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
