package org.dromara.service;


import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.houseInfo.bo.PropertyFeeBo;
import org.dromara.domain.houseInfo.vo.PropertyFeeVo;

import java.util.Collection;
import java.util.List;

/**
 * 物业费管理Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface IPropertyFeeService {

    /**
     * 查询物业费管理
     *
     * @param propertyId 主键
     * @return 物业费管理
     */
    PropertyFeeVo queryById(Long propertyId);

    /**
     * 分页查询物业费管理列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 物业费管理分页列表
     */
    TableDataInfo<PropertyFeeVo> queryPageList(PropertyFeeBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的物业费管理列表
     *
     * @param bo 查询条件
     * @return 物业费管理列表
     */
    List<PropertyFeeVo> queryList(PropertyFeeBo bo);

    /**
     * 新增物业费管理
     *
     * @param bo 物业费管理
     * @return 是否新增成功
     */
    Boolean insertByBo(PropertyFeeBo bo);

    /**
     * 修改物业费管理
     *
     * @param bo 物业费管理
     * @return 是否修改成功
     */
    Boolean updateByBo(PropertyFeeBo bo);

    /**
     * 校验并批量删除物业费管理信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
