package org.dromara.service;

import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.propertyRepair.bo.PropertyRepairBo;
import org.dromara.domain.propertyRepair.vo.PropertyRepairVo;

import java.util.Collection;
import java.util.List;

/**
 * 物业报修Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface IPropertyRepairService {

    /**
     * 查询物业报修
     *
     * @param repairId 主键
     * @return 物业报修
     */
    PropertyRepairVo queryById(Long repairId);

    /**
     * 分页查询物业报修列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 物业报修分页列表
     */
    TableDataInfo<PropertyRepairVo> queryPageList(PropertyRepairBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的物业报修列表
     *
     * @param bo 查询条件
     * @return 物业报修列表
     */
    List<PropertyRepairVo> queryList(PropertyRepairBo bo);

    /**
     * 新增物业报修
     *
     * @param bo 物业报修
     * @return 是否新增成功
     */
    Boolean insertByBo(PropertyRepairBo bo);

    /**
     * 修改物业报修
     *
     * @param bo 物业报修
     * @return 是否修改成功
     */
    Boolean updateByBo(PropertyRepairBo bo);

    /**
     * 校验并批量删除物业报修信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
