package org.dromara.service;


import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.houseInfo.bo.PropertySettingsBo;
import org.dromara.domain.houseInfo.vo.PropertySettingsVo;

import java.util.Collection;
import java.util.List;

/**
 * 物业费设置Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface IPropertySettingsService {

    /**
     * 查询物业费设置
     *
     * @param settingsId 主键
     * @return 物业费设置
     */
    PropertySettingsVo queryById(Long settingsId);

    /**
     * 分页查询物业费设置列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 物业费设置分页列表
     */
    TableDataInfo<PropertySettingsVo> queryPageList(PropertySettingsBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的物业费设置列表
     *
     * @param bo 查询条件
     * @return 物业费设置列表
     */
    List<PropertySettingsVo> queryList(PropertySettingsBo bo);

    /**
     * 新增物业费设置
     *
     * @param bo 物业费设置
     * @return 是否新增成功
     */
    Boolean insertByBo(PropertySettingsBo bo);

    /**
     * 修改物业费设置
     *
     * @param bo 物业费设置
     * @return 是否修改成功
     */
    Boolean updateByBo(PropertySettingsBo bo);

    /**
     * 校验并批量删除物业费设置信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
