package org.dromara.service;


import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.reservRecord.bo.ReservRecordBo;
import org.dromara.domain.reservRecord.vo.ReservRecordVo;

import java.util.Collection;
import java.util.List;

/**
 * 预约记录Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface IReservRecordService {

    /**
     * 查询预约记录
     *
     * @param reservRecordId 主键
     * @return 预约记录
     */
    ReservRecordVo queryById(Long reservRecordId);

    /**
     * 分页查询预约记录列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 预约记录分页列表
     */
    TableDataInfo<ReservRecordVo> queryPageList(ReservRecordBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的预约记录列表
     *
     * @param bo 查询条件
     * @return 预约记录列表
     */
    List<ReservRecordVo> queryList(ReservRecordBo bo);

    /**
     * 新增预约记录
     *
     * @param bo 预约记录
     * @return 是否新增成功
     */
    Boolean insertByBo(ReservRecordBo bo);

    /**
     * 修改预约记录
     *
     * @param bo 预约记录
     * @return 是否修改成功
     */
    Boolean updateByBo(ReservRecordBo bo);

    /**
     * 校验并批量删除预约记录信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
