package org.dromara.service;

import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.residentInfo.bo.ResidentInfoBo;
import org.dromara.domain.residentInfo.vo.ResidentInfoVo;

import java.util.Collection;
import java.util.List;

/**
 * 居住人员信息，存储居住人员的详细信息Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface IResidentInfoService {

    /**
     * 查询居住人员信息，存储居住人员的详细信息
     *
     * @param residentId 主键
     * @return 居住人员信息，存储居住人员的详细信息
     */
    ResidentInfoVo queryById(Long residentId);

    /**
     * 分页查询居住人员信息，存储居住人员的详细信息列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 居住人员信息，存储居住人员的详细信息分页列表
     */
    TableDataInfo<ResidentInfoVo> queryPageList(ResidentInfoBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的居住人员信息，存储居住人员的详细信息列表
     *
     * @param bo 查询条件
     * @return 居住人员信息，存储居住人员的详细信息列表
     */
    List<ResidentInfoVo> queryList(ResidentInfoBo bo);

    /**
     * 新增居住人员信息，存储居住人员的详细信息
     *
     * @param bo 居住人员信息，存储居住人员的详细信息
     * @return 是否新增成功
     */
    Boolean insertByBo(ResidentInfoBo bo);

    /**
     * 修改居住人员信息，存储居住人员的详细信息
     *
     * @param bo 居住人员信息，存储居住人员的详细信息
     * @return 是否修改成功
     */
    Boolean updateByBo(ResidentInfoBo bo);

    /**
     * 校验并批量删除居住人员信息，存储居住人员的详细信息信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
