package org.dromara.service;


import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.staffManage.bo.StaffManageBo;
import org.dromara.domain.staffManage.vo.StaffManageVo;

import java.util.Collection;
import java.util.List;

/**
 * 员工管理Service接口
 *
 * @author boman
 * @date 2025-04-10
 */
public interface IStaffManageService {

    /**
     * 查询员工管理
     *
     * @param staffId 主键
     * @return 员工管理
     */
    StaffManageVo queryById(Long staffId);

    /**
     * 获取员工管理详细信息
     *
     * @param userId 用户id
     */
    StaffManageVo getInfoByUserId(Long userId);

    /**
     * 分页查询员工管理列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 员工管理分页列表
     */
    TableDataInfo<StaffManageVo> queryPageList(StaffManageBo bo, PageQuery pageQuery);

    /**
     * 查询员工管理需要认证的列表
     */
    TableDataInfo<StaffManageVo> listAuthentication(StaffManageBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的员工管理列表
     *
     * @param bo 查询条件
     * @return 员工管理列表
     */
    List<StaffManageVo> queryList(StaffManageBo bo);

    /**
     * 新增员工管理
     *
     * @param bo 员工管理
     * @return 是否新增成功
     */
    Boolean insertByBo(StaffManageBo bo);
    /**
     * 管理员新增员工信息默认认证
     */
    Boolean insertAuthenticationByBo(StaffManageBo bo);

    /**
     * 修改员工管理
     *
     * @param bo 员工管理
     * @return 是否修改成功
     */
    Boolean updateByBo(StaffManageBo bo);

    /**
     * 管理员修改员工管理
     */
    Boolean editAuthentication(StaffManageBo bo);

    /**
     * 校验并批量删除员工管理信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);

    /**
     * 员工申请审核
     * @param bo
     * @return
     */
    Boolean examineStaff(StaffManageBo bo);

    /**
     * 删除员工信息和用户信息和权限
     * @param bo
     * @return
     */
    Boolean deleteStaffManage(StaffManageBo bo);
}
