package org.dromara.service;

import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.staffTrain.bo.StaffTrainManualBo;
import org.dromara.domain.staffTrain.vo.StaffTrainManualVo;

import java.util.Collection;
import java.util.List;

/**
 * 员工培训手册Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface IStaffTrainManualService {

    /**
     * 查询员工培训手册
     *
     * @param manualId 主键
     * @return 员工培训手册
     */
    StaffTrainManualVo queryById(Long manualId);

    /**
     * 分页查询员工培训手册列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 员工培训手册分页列表
     */
    TableDataInfo<StaffTrainManualVo> queryPageList(StaffTrainManualBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的员工培训手册列表
     *
     * @param bo 查询条件
     * @return 员工培训手册列表
     */
    List<StaffTrainManualVo> queryList(StaffTrainManualBo bo);

    /**
     * 新增员工培训手册
     *
     * @param bo 员工培训手册
     * @return 是否新增成功
     */
    Boolean insertByBo(StaffTrainManualBo bo);

    /**
     * 修改员工培训手册
     *
     * @param bo 员工培训手册
     * @return 是否修改成功
     */
    Boolean updateByBo(StaffTrainManualBo bo);

    /**
     * 校验并批量删除员工培训手册信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
