package org.dromara.service;

import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.staffTrainTime.bo.StaffTrainTimeBo;
import org.dromara.domain.staffTrainTime.vo.StaffTrainTimeVo;

import java.util.Collection;
import java.util.List;

/**
 * 员工培训时长Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface IStaffTrainTimeService {

    /**
     * 查询员工培训时长
     *
     * @param trainTimeId 主键
     * @return 员工培训时长
     */
    StaffTrainTimeVo queryById(Long trainTimeId);

    /**
     * 分页查询员工培训时长列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 员工培训时长分页列表
     */
    TableDataInfo<StaffTrainTimeVo> queryPageList(StaffTrainTimeBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的员工培训时长列表
     *
     * @param bo 查询条件
     * @return 员工培训时长列表
     */
    List<StaffTrainTimeVo> queryList(StaffTrainTimeBo bo);

    /**
     * 新增员工培训时长
     *
     * @param bo 员工培训时长
     * @return 是否新增成功
     */
    Boolean insertByBo(StaffTrainTimeBo bo);

    /**
     * 修改员工培训时长
     *
     * @param bo 员工培训时长
     * @return 是否修改成功
     */
    Boolean updateByBo(StaffTrainTimeBo bo);

    /**
     * 校验并批量删除员工培训时长信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
