package org.dromara.service;

import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.visitor.bo.VisitorManageBo;
import org.dromara.domain.visitor.vo.VisitorManageVo;

import java.util.Collection;
import java.util.List;

/**
 * 来访管理Service接口
 *
 * @author boman
 * @date 2025-04-11
 */
public interface IVisitorManageService {

    /**
     * 查询来访管理
     *
     * @param visitorManageId 主键
     * @return 来访管理
     */
    VisitorManageVo queryById(Long visitorManageId);

    /**
     * 分页查询来访管理列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 来访管理分页列表
     */
    TableDataInfo<VisitorManageVo> queryPageList(VisitorManageBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的来访管理列表
     *
     * @param bo 查询条件
     * @return 来访管理列表
     */
    List<VisitorManageVo> queryList(VisitorManageBo bo);

    /**
     * 新增来访管理
     *
     * @param bo 来访管理
     * @return 是否新增成功
     */
    Boolean insertByBo(VisitorManageBo bo);

    /**
     * 修改来访管理
     *
     * @param bo 来访管理
     * @return 是否修改成功
     */
    Boolean updateByBo(VisitorManageBo bo);

    /**
     * 校验并批量删除来访管理信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
